==> zio-aws-databasemigration_2.13-7.21.15.3-sources.jar: zio/aws/databasemigration/model/package.scala <==
package zio.aws.databasemigration
import zio.aws.databasemigration.model.primitives.Integer
import zio.aws.databasemigration.model.primitives.TStamp.Type
import java.time.Instant
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    type BooleanOptional = Boolean
    object CertificateWallet extends Subtype[Chunk[Byte]]
    type CertificateWallet =
      zio.aws.databasemigration.model.primitives.CertificateWallet.Type
    type DoubleOptional = Double
    type Integer = Int
    type IntegerOptional = Int
    object Iso8601DateTime extends Subtype[Instant]
    type Iso8601DateTime =
      zio.aws.databasemigration.model.primitives.Iso8601DateTime.Type
    type LongOptional = Long
    object SecretString extends Subtype[String]
    type SecretString =
      zio.aws.databasemigration.model.primitives.SecretString.Type
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.databasemigration.model.primitives.TStamp.Type
  }
  type AccountQuotaList = List[zio.aws.databasemigration.model.AccountQuota]
  type ArnList = List[String]
  type AssessmentReportTypesList =
    List[zio.aws.databasemigration.model.AssessmentReportType]
  type AvailabilityZonesList = List[String]
  type AvailableUpgradesList = List[String]
  type BatchStartRecommendationsErrorEntryList =
    List[zio.aws.databasemigration.model.BatchStartRecommendationsErrorEntry]
  type CertificateList = List[zio.aws.databasemigration.model.Certificate]
  type CollectorResponses =
    List[zio.aws.databasemigration.model.CollectorResponse]
  type CollectorsList =
    List[zio.aws.databasemigration.model.CollectorShortInfoResponse]
  type ConnectionList = List[zio.aws.databasemigration.model.Connection]
  type DataProviderDescriptorDefinitionList =
    List[zio.aws.databasemigration.model.DataProviderDescriptorDefinition]
  type DataProviderDescriptorList =
    List[zio.aws.databasemigration.model.DataProviderDescriptor]
  type DataProviderList = List[zio.aws.databasemigration.model.DataProvider]
  type DatabaseList = List[zio.aws.databasemigration.model.DatabaseResponse]
  type EndpointList = List[zio.aws.databasemigration.model.Endpoint]
  type EndpointSettingEnumValues = List[String]
  type EndpointSettingsList =
    List[zio.aws.databasemigration.model.EndpointSetting]
  type EngineVersionList = List[zio.aws.databasemigration.model.EngineVersion]
  type EventCategoriesList = List[String]
  type EventCategoryGroupList =
    List[zio.aws.databasemigration.model.EventCategoryGroup]
  type EventList = List[zio.aws.databasemigration.model.Event]
  type EventSubscriptionsList =
    List[zio.aws.databasemigration.model.EventSubscription]
  type ExcludeTestList = List[String]
  type FilterList = List[zio.aws.databasemigration.model.Filter]
  type FilterValueList = List[String]
  type FleetAdvisorLsaAnalysisResponseList =
    List[zio.aws.databasemigration.model.FleetAdvisorLsaAnalysisResponse]
  type FleetAdvisorSchemaList =
    List[zio.aws.databasemigration.model.SchemaResponse]
  type FleetAdvisorSchemaObjectList =
    List[zio.aws.databasemigration.model.FleetAdvisorSchemaObjectResponse]
  type IncludeTestList = List[String]
  type IndividualAssessmentNameList = List[String]
  type InstanceProfileList =
    List[zio.aws.databasemigration.model.InstanceProfile]
  type IntegerList = List[Integer]
  type KeyList = List[String]
  type LimitationList = List[zio.aws.databasemigration.model.Limitation]
  type MigrationProjectList =
    List[zio.aws.databasemigration.model.MigrationProject]
  type OrderableReplicationInstanceList =
    List[zio.aws.databasemigration.model.OrderableReplicationInstance]
  type PendingMaintenanceActionDetails =
    List[zio.aws.databasemigration.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.databasemigration.model.ResourcePendingMaintenanceActions]
  type RecommendationList = List[zio.aws.databasemigration.model.Recommendation]
  type ReplicationConfigList =
    List[zio.aws.databasemigration.model.ReplicationConfig]
  type ReplicationInstanceIpv6AddressList = List[String]
  type ReplicationInstanceList =
    List[zio.aws.databasemigration.model.ReplicationInstance]
  type ReplicationInstancePrivateIpAddressList = List[String]
  type ReplicationInstancePublicIpAddressList = List[String]
  type ReplicationInstanceTaskLogsList =
    List[zio.aws.databasemigration.model.ReplicationInstanceTaskLog]
  type ReplicationList = List[zio.aws.databasemigration.model.Replication]
  type ReplicationSubnetGroups =
    List[zio.aws.databasemigration.model.ReplicationSubnetGroup]
  type ReplicationTableStatisticsList =
    List[zio.aws.databasemigration.model.TableStatistics]
  type ReplicationTaskAssessmentResultList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentResult]
  type ReplicationTaskAssessmentRunList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentRun]
  type ReplicationTaskIndividualAssessmentList =
    List[zio.aws.databasemigration.model.ReplicationTaskIndividualAssessment]
  type ReplicationTaskList =
    List[zio.aws.databasemigration.model.ReplicationTask]
  type SchemaConversionRequestList =
    List[zio.aws.databasemigration.model.SchemaConversionRequest]
  type SchemaList = List[String]
  type SourceIdsList = List[String]
  type StartRecommendationsRequestEntryList =
    List[zio.aws.databasemigration.model.StartRecommendationsRequestEntry]
  type StringList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.databasemigration.model.Subnet]
  type SupportedEndpointTypeList =
    List[zio.aws.databasemigration.model.SupportedEndpointType]
  type TableListToReload = List[zio.aws.databasemigration.model.TableToReload]
  type TableStatisticsList =
    List[zio.aws.databasemigration.model.TableStatistics]
  type TagList = List[zio.aws.databasemigration.model.Tag]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.databasemigration.model.VpcSecurityGroupMembership]
}

==> zio-aws-databasemigration_3-5.17.182.1-sources.jar: zio/aws/databasemigration/model/package.scala <==
package zio.aws.databasemigration
import zio.aws.databasemigration.model.primitives.Integer
import zio.aws.databasemigration.model.primitives.TStamp.Type
import java.time.Instant
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    type BooleanOptional = Boolean
    object CertificateWallet extends Subtype[Chunk[Byte]]
    type CertificateWallet =
      zio.aws.databasemigration.model.primitives.CertificateWallet.Type
    type Integer = Int
    type IntegerOptional = Int
    object SecretString extends Subtype[String]
    type SecretString =
      zio.aws.databasemigration.model.primitives.SecretString.Type
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.databasemigration.model.primitives.TStamp.Type
  }
  type AccountQuotaList = List[zio.aws.databasemigration.model.AccountQuota]
  type ArnList = List[String]
  type AvailabilityZonesList = List[String]
  type CertificateList = List[zio.aws.databasemigration.model.Certificate]
  type ConnectionList = List[zio.aws.databasemigration.model.Connection]
  type EndpointList = List[zio.aws.databasemigration.model.Endpoint]
  type EndpointSettingEnumValues = List[String]
  type EndpointSettingsList =
    List[zio.aws.databasemigration.model.EndpointSetting]
  type EventCategoriesList = List[String]
  type EventCategoryGroupList =
    List[zio.aws.databasemigration.model.EventCategoryGroup]
  type EventList = List[zio.aws.databasemigration.model.Event]
  type EventSubscriptionsList =
    List[zio.aws.databasemigration.model.EventSubscription]
  type ExcludeTestList = List[String]
  type FilterList = List[zio.aws.databasemigration.model.Filter]
  type FilterValueList = List[String]
  type IncludeTestList = List[String]
  type IndividualAssessmentNameList = List[String]
  type IntegerList = List[Integer]
  type KeyList = List[String]
  type OrderableReplicationInstanceList =
    List[zio.aws.databasemigration.model.OrderableReplicationInstance]
  type PendingMaintenanceActionDetails =
    List[zio.aws.databasemigration.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.databasemigration.model.ResourcePendingMaintenanceActions]
  type ReplicationInstanceList =
    List[zio.aws.databasemigration.model.ReplicationInstance]
  type ReplicationInstancePrivateIpAddressList = List[String]
  type ReplicationInstancePublicIpAddressList = List[String]
  type ReplicationInstanceTaskLogsList =
    List[zio.aws.databasemigration.model.ReplicationInstanceTaskLog]
  type ReplicationSubnetGroups =
    List[zio.aws.databasemigration.model.ReplicationSubnetGroup]
  type ReplicationTaskAssessmentResultList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentResult]
  type ReplicationTaskAssessmentRunList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentRun]
  type ReplicationTaskIndividualAssessmentList =
    List[zio.aws.databasemigration.model.ReplicationTaskIndividualAssessment]
  type ReplicationTaskList =
    List[zio.aws.databasemigration.model.ReplicationTask]
  type SchemaList = List[String]
  type SourceIdsList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.databasemigration.model.Subnet]
  type SupportedEndpointTypeList =
    List[zio.aws.databasemigration.model.SupportedEndpointType]
  type TableListToReload = List[zio.aws.databasemigration.model.TableToReload]
  type TableStatisticsList =
    List[zio.aws.databasemigration.model.TableStatistics]
  type TagList = List[zio.aws.databasemigration.model.Tag]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.databasemigration.model.VpcSecurityGroupMembership]
}
